@@ -459,8 +459,6 @@ def create_job(
 
             volumes = " ".join([volume or "main" for volume in volumes_per_map[map_name]])
 
-    executable = executable or "LinuxServer/KamoOneProject/Binaries/Linux/KamoOneProjectServer"
-
     args = [c.strip() for c in custom_args.split(",")]
     if not s3_path:
         versions = {}
@@ -475,21 +473,26 @@ def create_job(
         else:
             version = list(versions.keys())[0]
         s3_path = versions[version]["s3_path"]
-    else:
-        client = boto3.client("s3")
-        parts = urlparse(s3_path)
-        bucket_name = parts.netloc
-        prefix = parts.path[1:]
 
-        try:
-            f = BytesIO()
-            client.download_fileobj(bucket_name, prefix + "buildinfo.json", f)
-            f.seek(0)
-            build_info = json.load(f)
-            if not version:
-                version = build_info.get("version", "N/A")
-        except Exception as e:
-            secho(f"Could not load buildinfo.json from {s3_path}. Was the path correct? Error: {e}", fg="red")
+    client = boto3.client("s3")
+    parts = urlparse(s3_path)
+    bucket_name = parts.netloc
+    prefix = parts.path[1:]
+
+    try:
+        f = BytesIO()
+        client.download_fileobj(bucket_name, prefix + "buildinfo.json", f)
+        f.seek(0)
+        build_info = json.load(f)
+        if not version:
+            version = build_info.get("version", "N/A")
+        if not executable:
+            executable = build_info.get("executable")
+    except Exception as e:
+        secho(f"Could not load buildinfo.json from {s3_path}. Was the path correct? Error: {e}", fg="red")
+
+    if not executable:
+        abort("You must specify an executable to run. e.fg. 'LinuxServer/TestProject/Binaries/Linux/TestProject'")
 
     all_nodes = find_nodes(ctx)
     if node_id:
@@ -511,7 +514,7 @@ def create_job(
 
     if not is_force:
         confirm(
-            f"Do you want to create {len(launches)} jobs with version '{version}' from '{s3_path}' on the '{tenant}' tenant?",
+            f"Do you want to create {len(launches)} jobs with version '{version}' from '{s3_path}' on the '{tenant}' tenant with executable '{executable}'?",
             abort=True,
         )
 
