@@ -150,7 +150,8 @@ def _prepare_profile(profile):
             ret["domain"] = profile["domain"]
         else:
             ret["domain"] = domain_from_api_key(ret["api_key"])
-    except Exception:
+    except Exception as e:
+        log.error(f"Error preparing profile {profile}: {e}")
         return None
     return ret
 
